@@ -19,7 +19,7 @@ def main():
         print('File exists, overwrite? (y/n)')
         if input() == 'y':
             print(__name__)
-            data = pkgutil.get_data(__name__, "predictor-template.py")
+            data = pkgutil.get_data(__name__, "../predictor-template.py")
             if data is None:
                 print('Failed to load predictor-template.py')
                 return
