@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 
 # -- stdlib --
-import functools
 import os
 import sys
 
@@ -9,7 +8,15 @@ import sys
 # -- own --
 
 # -- code --
-@functools.lru_cache(1)
+class ServingError(Exception):
+
+    def __init__(self, message, status_code=400, payload={}):
+        Exception.__init__(self)
+        self.message = message
+        self.status_code = status_code
+        self.payload = {**payload, 'error': message}
+
+
 def detect_env():
     if sys.platform == 'win32':
         return 'local'
